@@ -4,14 +4,18 @@
 #' Process a multiblock JCAMP-DX file into separate files, one for each data set.
 #'
 #' @section Warning:
-#' \pkg{Individual data sets are written into the current directory, so you probably want to
-#' work on a copy of the data for this task}.
+#' \pkg{Individual data sets are written into the current directory if you set \code{subdir}
+#' to \code{NULL}, so you may want to work on a copy of the data in this case}.
 #'
 #' @param file Length one character giving the name of the multiblock file.
+#' @param subdir Character.  If not \code{NULL}, a subdirectory by this name will be 
+#'        created in the working directory, and the individual files will be placed
+#'        in this subdirectory.  If the subdirectory already exists, an error will be thrown.
 #'
 #' @return A list is returned invisibly that has one DX data set per list element.  \pkg{Individual files
-#'        are written into the current directory, so you probably want to work on a copy of the data
-#'        for this task}.  File names are extracted from the
+#'        are written into the current directory if \code{subdir = NULL}, so you probably want
+#'        to work on a copy of the data
+#'        in this case}.  File names are extracted from the
 #'        \code{##TITLE= sample_name} field and will be \code{sample_name} (more precisely,
 #'        the name will be whatever follows \code{##TITLE=} on the line).  If
 #'        sample names are duplicated the output files will be overwritten as the file
@@ -27,7 +31,7 @@
 #'
 #' @export
 #'
-splitMultiblockDX <- function(file = NULL) {
+splitMultiblockDX <- function(file = NULL, subdir = "data_sets") {
 
   if (is.null(file)) stop("You must provide a file name")
   if (length(file) > 1) stop("Please give a single file name")
@@ -67,6 +71,14 @@ splitMultiblockDX <- function(file = NULL) {
   }
   names(blocks) <- fnames
 
+  # Create a subdirectory if requested & add to file names
+  if (!is.null(subdir)) {
+    if (dir.exists(subdir)) stop("subdir already exists!")
+    dir.create(subdir)
+    fnames <- paste(subdir, fnames, sep = "/")
+  }
+
+
   # Write it out
   for (i in 1:nb) writeLines(blocks[[i]], paste(fnames[i], "dx", sep = "."))
 
